# Contribution Guidelines

Thank you for considering contributing to the contract information repository! To maintain quality and consistency, please follow the guidelines below.

## Table of Contents

1. [General Rules](#general-rules)
2. [Adding a New Contract](#adding-a-new-contract)
3. [Updating an Existing Contract](#updating-an-existing-contract)
4. [Document Format](#document-format)
5. [Commit Messages](#commit-messages)
6. [Pull Request Process](#pull-request-process)
7. [Review and Approval](#review-and-approval)
8. [Contact Information](#contact-information)

## General Rules

- Ensure that all contributions are relevant to the scope of this repository, focusing on contract-related information between **Warky Devs Pty Ltd** and **Vivarox**.
- All contributions must comply with the confidentiality agreements in place.
- Only authorized personnel should contribute or have access to this repository.

## Adding a New Contract

1. **Create a New Directory**: If the contract is for a new year, create a new directory under the `/contracts` directory with the year as its name (e.g., `/contracts/2025`).

2. **File Naming**: Name the contract file using the format: `WarkyDevs_Vivarox_[ContractType]_[Date].pdf`. Example: `WarkyDevs_Vivarox_ServiceAgreement_2024-08-01.pdf`.

3. **Upload the Document**: Place the contract file in the appropriate directory.

4. **Update the README**: Add a link to the new contract document in the [README](README.md) file under the relevant section.

## Updating an Existing Contract

1. **Locate the Document**: Find the existing contract file in the repository.

2. **Make Edits**: Use appropriate software to make necessary changes to the contract document.

3. **Versioning**: If significant changes are made, create a new version of the file with a version number. Example: `WarkyDevs_Vivarox_ServiceAgreement_v2_2024-08-15.pdf`.

4. **Update the README**: Reflect the changes in the [README](README.md) file, specifying the new version.

## Document Format

- All contracts should be in PDF format.
- Supporting documents, templates, or guidelines should be in Markdown (`.md`) format.

## Commit Messages

- Use clear and descriptive commit messages.
- Format: `[Type]: Brief description of the change`
  - Example: `Add: New NDA template for 2024`
  - Example: `Update: Revised confidentiality agreement`

## Pull Request Process

1. **Fork the Repository**: Start by forking the repository to your own GitHub account.

2. **Create a Branch**: Create a new branch with a descriptive name related to your changes. Example: `add-nda-template-2024`.

    ```bash
    git checkout -b add-nda-template-2024
    ```

3. **Make Changes**: Add or update the relevant documents and commit your changes to your branch.

4. **Submit a Pull Request (PR)**: Once your changes are committed, open a PR against the `main` branch of the repository. Provide a clear description of the changes made.

## Review and Approval

- All pull requests will be reviewed by the repository maintainers.
- Ensure all files are correctly formatted and links are functional before requesting a review.
- Once approved, the PR will be merged into the `main` branch.

## Contact Information

For any questions or further clarifications, please contact:

- **Hein** - Contract Manager at Warky Devs Pty Ltd
- **Email**: admin@warky.dev
- **Phone**: +27 (0)872653704

---

**Warky Devs Pty Ltd**  
3 Louw Wepener Street SE1, Vanderbijlpark, South Africa

**Vivarox**  
534 Sakabuka Street, Derdepoort, Pretoria, South Africa
